@@ -7,21 +7,33 @@ POSTS_TABLE_NAME = 'posts'
 
 
 class Version1(MigrationVersion):
+    @staticmethod
+    def users_table_name(table_prefix: str) -> str:
+        if table_prefix:
+            return f'{table_prefix}_{USERS_TABLE_NAME}'
+        return USERS_TABLE_NAME
+
+    @staticmethod
+    def posts_table_name(table_prefix: str) -> str:
+        if table_prefix:
+            return f'{table_prefix}_{POSTS_TABLE_NAME}'
+        return POSTS_TABLE_NAME
+
     def get_version(self) -> int:
         return 1
 
-    def do(self, engine, schema=None) -> None:
+    def do(self, engine, table_prefix=None, schema=None) -> None:
         meta = MetaData(schema=schema)
 
         Table(
-            USERS_TABLE_NAME, meta,
+            self.users_table_name(table_prefix), meta,
             Column('id', Integer, primary_key=True, autoincrement=True),
             Column('username', String(128), nullable=False),
             Column('encrypted_password', String(512), nullable=False)
         )
 
         Table(
-            POSTS_TABLE_NAME, meta,
+            self.posts_table_name(table_prefix), meta,
             Column('id', Integer, primary_key=True, autoincrement=True),
             Column('title', String(256), nullable=False),
             Column('author', String(128), nullable=False),
@@ -31,6 +43,7 @@ class Version1(MigrationVersion):
 
         meta.create_all(engine)
 
-    def undo(self, engine, schema=None) -> None:
+    def undo(self, engine, table_prefix=None, schema=None) -> None:
         meta = MetaData(schema=schema)
-        meta.drop_all(bind=engine, tables=['users, posts'])
+        meta.drop_all(bind=engine,
+                      tables=[self.users_table_name(table_prefix), self.posts_table_name(table_prefix)])
